@@ -7,6 +7,7 @@
 # Claudio M. Perez
 #
 import warnings
+from collections import defaultdict
 import numpy as np
 Array = np.ndarray
 
@@ -487,7 +488,7 @@ class FrameArtist:
         lines  = []
         quadrs = []
         trians = []
-        solids = []
+        strokes = defaultdict(list)
         for tag in model.iter_cell_tags():
 
             if model.cell_matches(tag, "plane") and config["plane"]["show"]:
@@ -501,7 +502,8 @@ class FrameArtist:
                 # TODO: get cell faces
                 idx = model.cell_exterior(tag)
                 if idx:
-                    solids.append(idx)
+                    strokes[len(idx)].append(idx)
+                    # solids.append(idx)
             
             elif model.cell_matches(tag, "truss"):
                 lines.append(model.cell_exterior(tag))
@@ -524,9 +526,14 @@ class FrameArtist:
             self.canvas.plot_lines("node_vertices", indices=np.array(trians),
                                    style=config["plane"]["style"])
 
-        if len(solids) > 0 and config["solid"]["show"]:
-            self.canvas.plot_lines("node_vertices", indices=np.array(solids),
-                                          style=config["solid"]["style"])
+        # if len(solids) > 0 and config["solid"]["show"]:
+        #     self.canvas.plot_lines("node_vertices", indices=np.array(solids),
+        #                                   style=config["solid"]["style"])
+        
+        for group in strokes.values():
+            if len(group):
+                self.canvas.plot_lines("node_vertices", indices=np.array(group),
+                                            style=config["solid"]["style"])
 
         if len(lines) > 0:
             self.canvas.plot_lines("node_vertices", indices=np.array(lines),
