@@ -340,7 +340,7 @@ def read_state(res_file,
 
         if callable(rotation) and model.ndm==2:
             rotation_state = GroupStateSO3(
-                {k: Rotation.from_rotvect([0,0,rotation(k)]) for k in model.iter_node_tags()},
+                {k: Rotation.from_rotvec([0,0,rotation(k)]) for k in model.iter_node_tags()},
                 model,
                 transform=transform[3:,3:],
                 time=time,
@@ -819,7 +819,8 @@ class FrameModel:
         e1  = v1/L
 
         if self.ndm == 2:
-            v2 = -np.cross(e1, np.array([0, 0, 1]))
+            v2 =  -np.cross(e1, np.array([0, 0, 1]))
+            # v2 =   np.cross(e1, np.array([0, 1, 0]))
 
         if "yvec" in el["trsfm"] and el["trsfm"]["yvec"] is not None:
             v2  = np.array(el["trsfm"]["yvec"])
